# -*- coding: utf-8 -*-
from django.db import models
from django.conf import settings
from django.utils.translation import ugettext as _
from cms.models.pluginmodel import CMSPlugin



class NewsSettings(CMSPlugin):

    category_slug = models.SlugField(
        _("Category slug"),
        max_length=100,
        blank=True,
        help_text=_("(Optional)News category slug(s) filter")
    )
    slug = models.SlugField(
        _("Slug"),
        max_length=100,
        blank=True,
        help_text=_("(Optional)News slug(s) filter")
    )
    exclusion_category_slug = models.SlugField(
        _("Excluding category slugs"),
        max_length=100, blank=True,
        help_text=_("(Optional)excluding News category slug(s) filter")
    )
    exclusion_slug = models.SlugField(
        _("Excluding slugs"),
        max_length=100, blank=True,
        help_text=_("(Optional)excluding News slug(s) filter")
    )

    pub_date_begin = models.DateTimeField(
        blank=True,
        null=True,
        verbose_name=_('Publication date begin'),
        help_text=_('News publication start date'),
    )
    pub_date_end = models.DateTimeField(
        blank=True,
        null=True,
        verbose_name=_('Publication date end'),
        help_text=_('When news publication date ends.'),
    )

    objects_per_page = models.IntegerField(default=10)
    ordering = models.CharField(max_length=100, default='ordering, event_date, title')
    template_name = models.CharField(
        max_length=100,
        choices=settings.NEWS_CMSPLUGIN_TEMPLATES,
        default="cms_plugins/news_box_wide.html"
    )

    class Meta:
        app_label = "news"

    def __unicode__(self):
        return self.template_name


class NewsSidebarSettings(CMSPlugin):

    date_begin = models.DateField(
        _('Start date'),
        blank=True,
        null=True,
        help_text=_('Start date range'),
    )

    date_end = models.DateField(
        _('End date'),
        blank=True,
        null=True,
        help_text=_('End date range'),
    )

    ordering = models.CharField(max_length=100, default='-event_date')

    category_slug = models.SlugField(
        _("Category slug"),
        max_length=100,
        blank=True,
        help_text=_("(Optional)News category slug(s) filter")
    )
    slug = models.SlugField(
        _("Slug"),
        max_length=100,
        blank=True,
        help_text=_("(Optional)News slug(s) filter")
    )

    exclusion_category_slug = models.SlugField(
        _("Excluding category slugs"),
        max_length=100, blank=True,
        help_text=_("(Optional)excluding News category slug(s) filter")
    )

    exclusion_slug = models.SlugField(
        _("Excluding slugs"),
        max_length=100, blank=True,
        help_text=_("(Optional)excluding News slug(s) filter")
    )

    template_name = models.CharField(
        max_length=100,
        choices=settings.NEWS_CMSPLUGIN_TEMPLATES,
        default="cms_plugins/news_sidebar.html"
    )
