from django.core.paginator import Paginator
from django.utils.translation import ugettext as _

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from jmb.news.models import News, Category
from jmb.news.cms.models import NewsSettings, NewsSidebarSettings



class NewsPlugin(CMSPluginBase):
    model = NewsSettings
    name = _("News List")
    module = _("News")


    def render(self, context, instance, placeholder):
        page = 1
        self.render_template = instance.template_name
        ordering = instance.ordering.lower().replace(" ","").split(",")

        objects = News.objects.filter(status=1)

        if instance.slug:
            slugs = instance.slug.lower().replace(" ","").split(",")
            objects = objects.filter(slug__in = slugs)
        if instance.category_slug:
            category_slugs = instance.category_slug.lower().replace(" ","").split(",")
            objects = objects.filter(categories__slug__in = category_slugs)
        if instance.exclusion_slug:
            exclusion_slugs = instance.exclusion_slug.lower().replace(" ","").split(",")
            objects = objects.exclude(slug__in = exclusion_slugs)
        if instance.exclusion_category_slug:
            exclusion_category_slugs = instance.exclusion_category_slug.lower().replace(" ","").split(",")
            objects = objects.exclude(categories__slug__in = exclusion_category_slugs)
        if instance.pub_date_begin:
            objects = objects.filter(event_date__gte= instance.pub_date_begin)
        if instance.pub_date_end:
            objects = objects.filter(event_date__lte= instance.pub_date_end)

        objects = objects.order_by(*ordering)
        paginator = Paginator(objects, instance.objects_per_page)

        objects = paginator.page(page)

        context.update({
            'objects': objects,
            'instance': instance,
            'placeholder': placeholder,
            })
        return context


plugin_pool.register_plugin(NewsPlugin)



class NewsSidebar(CMSPluginBase):

    model = NewsSidebarSettings
    name = _("News Sidebar")
    module = _("News")

    def render(self, context, instance, placeholder):
        self.render_template = instance.template_name
        ordering = instance.ordering.lower().replace(" ","").split(",")

        objects = News.objects.filter(status=1)
        objects = objects.dates('event_date','month').order_by(*ordering)
#        import ipdb; ipdb.set_trace()
#        for m in objects:
#            m
#            pass
        context.update({
            'objects': objects,
            'instance': instance,
            'placeholder': placeholder,
            })
        return context

#plugin_pool.register_plugin(NewsSidebar)